GgufError

Enum GgufError 

#[non_exhaustive]
pub enum GgufError {
Show 13 variants NotFile, InvalidPathUtf8, UnsupportedExtension, InteriorNul, InvalidUtf8, ArrayKeyAlreadyExists { key: String, }, MetadataKeyAlreadyExists { key: String, }, WrongMetadataKind { key: String, expected: GgufMetadataKind, actual: GgufMetadataKind, }, UnsupportedTensorDtype { dtype: Dtype, }, UnsupportedMetadataArrayDtype { dtype: Dtype, }, InvalidMetadataArrayRank { rank: usize, }, EmptyMetadataArray, Exception(Exception),
}
An error from GGUF validation or an upstream MLX operation.

Stable Rust-side validation failures have dedicated variants. Other native runtime failures remain opaque in GgufError::Exception.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NotFile

The load path is not an existing local file.



InvalidPathUtf8

The path cannot be represented by the C string ABI.



UnsupportedExtension

The path does not end in .gguf.



InteriorNul

A path, key, or value contains an interior null byte.



InvalidUtf8

Text returned by the native API is not valid UTF-8.



ArrayKeyAlreadyExists

The array namespace already contains this key.

Fields

key: String

The duplicate array key.



MetadataKeyAlreadyExists

The metadata namespace already contains this key.

Fields

key: String

The duplicate metadata key.



WrongMetadataKind

A typed getter was used for a different metadata kind.

Fields

key: String

The metadata key.

expected: GgufMetadataKind

The kind requested by the getter.

actual: GgufMetadataKind

The kind stored in the container.



UnsupportedTensorDtype

The tensor dtype is not supported by the MLX 0.32.2 GGUF writer.

Fields

dtype: Dtype

The rejected dtype.



UnsupportedMetadataArrayDtype

The metadata-array dtype is not supported by the MLX 0.32.2 GGUF writer.

Fields

dtype: Dtype

The rejected dtype.



InvalidMetadataArrayRank

Metadata arrays may only be scalar or one-dimensional.

Fields

rank: usize

The rejected array rank.



EmptyMetadataArray

Metadata arrays must contain at least one element.



Exception(Exception)

An opaque error reported by MLX.